Module pipeline
tidepool_
optimize
0.1.0
Module pipeline
Module Items
Structs
Constants
Functions
In crate tidepool_
optimize
tidepool_optimize
Module
pipeline
Structs

Pipeline
Stats
Statistics from a pipeline run.
Constants

MAX_
PIPELINE_
ITERATIONS
Maximum number of iterations for the pipeline to avoid infinite loops.
Functions

default_
passes
Returns the default optimization pass sequence. Order: BetaReduce → Inline → CaseReduce → Dce → PartialEval.
optimize
Run the default optimization pipeline to fixed point.
run_
pass_
to_
fixpoint
Run a single pass to fixed point (convenience). Returns the number of times the pass reported a change.
run_
pipeline
Run a sequence of passes to fixed point. Keeps iterating until no pass reports a change or MAX_PIPELINE_ITERATIONS is reached. Returns stats about how many iterations and per-pass invocations.